PyLadies
========

Release v\ |version| (:doc:`What's new? <changelog>`).

.. include:: intro.rst
   :start-after: :orphan:


Quickstart
----------

.. toctree::

   getting-started
   overview
   about


Deeper Dive
-----------

.. toctree::

   history
   background
   policies
   faqs
   contact


How do I...?
------------

.. toctree::

   advice
   events
   promotion
   website
   newsletter
   relationships


Extras
------

.. toctree::

   swag
   tools
   resources
